@@ -9,6 +9,8 @@
 
 package Testcase::Spec::Disabled;
 use Test::Spec;
+use FindBin qw($Bin);
+BEGIN { require "$Bin/test_helper.pl" };
 
 describe 'Test::Spec' => sub {
   xdescribe 'disabled spec' => sub {
